<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<div id="fb-root"></div> <script async="1" defer="1" crossorigin="anonymous" src="https://connect.facebook.net/es_ES/sdk.js#xfbml=1&amp;version=v25.0"></script><div class="fb-post" data-href="https://www.facebook.com/permalink.php?story_fbid=827163017327807&amp;id=149460691764713" data-width="552"></div>',
        'width' => 552,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Aquí vos deixamos unhas imaxes da nosa visita do pasado sábado á Guarda. Moi agradecidos á Asociación Naturalista do Baixo Miño www.anabam.org e a Malde Arqueoloxía',
    'favicon' => 'https://static.xx.fbcdn.net/rsrc.php/y1/r/ay1hV6OlegS.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://scontent.fmad7-1.fna.fbcdn.net/v/t39.30808-6/555561618_24950042437946528_7655136112008588820_n.jpg?stp=dst-jpg_tt6&cstp=mx1200x804&ctp=p600x600&_nc_cat=102&ccb=1-7&_nc_sid=cae128&_nc_ohc=qBGak5ClPCgQ7kNvwGXb6Cu&_nc_oc=AdpWXAmvUCjkYskYXeRrR_rmhp-SucELnRMMv2vTHNyrnqVfci4nWA0uKBqJxmGD8BM&_nc_zt=23&_nc_ht=scontent.fmad7-1.fna&_nc_gid=dmF5omR3TbyHO1C5nPW46w&_nc_ss=7b20f&oh=00_AQALojV3CDrx2G77tdP2guLSnuRgiwEmOy38wIXHv7NJnQ&oe=6A54685D',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'Facebook',
    'providerUrl' => 'https://www.facebook.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Aquí vos deixamos unhas... - DAG, Asociación Galega de Deseño',
    'url' => 'https://www.facebook.com/permalink.php?story_fbid=827163017327807&id=149460691764713',
    'linkedData' => [],
    'oEmbed' => [
        'provider_url' => 'https://www.facebook.com',
        'provider_name' => 'Facebook',
        'html' => '<div id="fb-root"></div>
<script async="1" defer="1" crossorigin="anonymous" src="https://connect.facebook.net/es_ES/sdk.js#xfbml=1&amp;version=v25.0"></script><div class="fb-post" data-href="https://www.facebook.com/permalink.php?story_fbid=827163017327807&amp;id=149460691764713" data-width="552"></div>',
        'type' => 'rich',
        'version' => '1.0',
        'width' => 552
    ],
    'allLinkedData' => []
];
