<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<div id="fb-root"></div> <script async="1" defer="1" crossorigin="anonymous" src="https://connect.facebook.net/es_ES/sdk.js#xfbml=1&amp;version=v25.0"></script><div class="fb-video" data-href="https://www.facebook.com/acolono/videos/10154107990797381/"><blockquote cite="https://www.facebook.com/acolono/videos/10154107990797381/" class="fb-xfbml-parse-ignore"><a href="https://www.facebook.com/acolono/videos/10154107990797381/"></a><p>Eindrücke vom gestrigen Drupal Austria Meetup bei uns im Büro :) Wir haben die beste Community!</p>Posted by <a href="https://www.facebook.com/acolono">Acolono GmbH</a> on Thursday, May 12, 2016</blockquote></div>',
        'width' => 500,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'Eindrücke vom gestrigen Drupal Austria Meetup bei uns im Büro :) Wir haben die beste Community!',
    'favicon' => 'https://static.xx.fbcdn.net/rsrc.php/y1/r/ay1hV6OlegS.ico',
    'feeds' => [],
    'icon' => null,
    'image' => null,
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'Facebook',
    'providerUrl' => 'https://www.facebook.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Eindrücke vom gestrigen Drupal Austria Meetup bei uns im Büro :) Wir haben die beste Community! | Acolono GmbH',
    'url' => 'https://www.facebook.com/acolono/videos/10154107990797381/',
    'linkedData' => [],
    'oEmbed' => [
        'provider_url' => 'https://www.facebook.com',
        'provider_name' => 'Facebook',
        'html' => '<div id="fb-root"></div>
<script async="1" defer="1" crossorigin="anonymous" src="https://connect.facebook.net/es_ES/sdk.js#xfbml=1&amp;version=v25.0"></script><div class="fb-video" data-href="https://www.facebook.com/acolono/videos/10154107990797381/"><blockquote cite="https://www.facebook.com/acolono/videos/10154107990797381/" class="fb-xfbml-parse-ignore"><a href="https://www.facebook.com/acolono/videos/10154107990797381/"></a><p>Eindrücke vom gestrigen Drupal Austria Meetup bei uns im Büro :) Wir haben die beste Community!</p>Posted by <a href="https://www.facebook.com/acolono">Acolono GmbH</a> on Thursday, May 12, 2016</blockquote></div>',
        'type' => 'video',
        'version' => '1.0',
        'width' => 500
    ],
    'allLinkedData' => []
];
